@@ -79,7 +79,7 @@ class JointBase(BackendGeom, ABC):
     def _cut_intersecting_member(self, mem_base: Beam, mem_incoming: Beam):
         from ada import PrimBox
 
-        p1, p2 = mem_base.bbox.minmax
+        p1, p2 = mem_base.bbox().minmax
         mem_incoming.add_penetration(PrimBox(f"{self.name}_neg", p1, p2))
 
     def _get_landing_member(self, members) -> Beam:
