@@ -1,11 +1,11 @@
 from __future__ import annotations
 
-import logging
 from typing import TYPE_CHECKING, Iterable, List, Union
 
 import numpy as np
 
-from ada.config import Settings
+from ada.base.units import Units
+from ada.config import Settings, get_logger
 from ada.core.vector_utils import vector_length
 
 if TYPE_CHECKING:
@@ -14,13 +14,14 @@ if TYPE_CHECKING:
     from ada.fem import Bc, Csys, Elem
 
 numeric = Union[int, float, np.number]
+logger = get_logger()
 
 
 class Node:
     """Base node object"""
 
     def __init__(
-        self, p: Iterable[numeric, numeric, numeric], nid=None, bc=None, r=None, parent=None, units="m", refs=None
+        self, p: Iterable[numeric, numeric, numeric], nid=None, bc=None, r=None, parent=None, units=Units.M, refs=None
     ):
         self._id = nid
         self.p: np.ndarray = np.array([*p], dtype=np.float64) if type(p) != np.ndarray else p
@@ -74,13 +75,13 @@ class Node:
         if item not in self.refs:
             self.refs.append(item)
         else:
-            logging.debug(f"Item {item} is already in node refs {self}")
+            logger.debug(f"Item {item} is already in node refs {self}")
 
     def remove_obj_from_refs(self, item) -> None:
         if item in self.refs:
             self.refs.remove(item)
         else:
-            logging.debug(f"Item {item} is not in node refs {self}")
+            logger.debug(f"Item {item} is not in node refs {self}")
 
     @property
     def units(self):
@@ -88,10 +89,11 @@ class Node:
 
     @units.setter
     def units(self, value):
+        if isinstance(value, str):
+            value = Units.from_str(value)
         if value != self._units:
-            from ada.core.utils import unit_length_conversion
+            scale_factor = Units.get_scale_factor(self._units, value)
 
-            scale_factor = unit_length_conversion(self._units, value)
             self.p_roundoff(scale_factor)
 
             if self._r is not None:
@@ -165,7 +167,7 @@ def get_singular_node_by_volume(nodes: Nodes, p: np.ndarray, tol=Settings.point_
     if len(nds) > 0:
         node, *other_nodes = nds
         if len(other_nodes) > 0:
-            logging.warning(f"More than 1 node within point {p}, other nodes: {other_nodes}. Returns node {node}")
+            logger.warning(f"More than 1 node within point {p}, other nodes: {other_nodes}. Returns node {node}")
         return node
     else:
         return Node(p)
@@ -197,7 +199,7 @@ def replace_nodes_by_tol(nodes, decimals=0, tol=Settings.point_tol):
         elif not most_precise[0] and np.any(most_precise[1:]):
             return False
         elif decimals_ == 10:
-            logging.error(f"Recursion started at 0 decimals, but are now at {decimals_} decimals. Will proceed with n.")
+            logger.error(f"Recursion started at 0 decimals, but are now at {decimals_} decimals. Will proceed with n.")
             return True
         else:
             return n_is_most_precise(n, nearby_nodes_, decimals_ + 1)
@@ -223,4 +225,4 @@ def replace_node(old_node: Node, new_node: Node) -> None:
         old_node.remove_obj_from_refs(obj)
         new_node.add_obj_to_refs(obj)
 
-        logging.debug(f"{old_node} exchanged with {new_node} --> {obj}")
+        logger.debug(f"{old_node} exchanged with {new_node} --> {obj}")
