@@ -1,7 +1,6 @@
 # coding=utf-8
 from __future__ import annotations
 
-import logging
 import os
 import pathlib
 import shutil
@@ -11,11 +10,13 @@ from typing import TYPE_CHECKING, Any, Dict, Union
 
 import numpy as np
 
-from ada.config import Settings
+from ada.config import Settings, get_logger
 
 if TYPE_CHECKING:
     from ada import Node
 
+logger = get_logger()
+
 
 class NewLine:
     def __init__(self, n, prefix=None, suffix=None):
@@ -176,7 +177,7 @@ def traverse_hdf_datasets(hdf_file):
                 yield from h5py_dataset_iterator(item, path)
 
     with h5py.File(hdf_file, "r") as f:
-        for (path, dset) in h5py_dataset_iterator(f):
+        for path, dset in h5py_dataset_iterator(f):
             print(path, dset)
 
     return None
@@ -219,6 +220,24 @@ def zip_dir(directory, zip_path, incl_only=None):
                 )
 
 
+def is_within_directory(directory, target):
+    abs_directory = os.path.abspath(directory)
+    abs_target = os.path.abspath(target)
+
+    prefix = os.path.commonprefix([abs_directory, abs_target])
+
+    return prefix == abs_directory
+
+
+def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+    for member in tar.getmembers():
+        member_path = os.path.join(path, member.name)
+        if not is_within_directory(path, member_path):
+            raise Exception("Attempted Path Traversal in Tar File")
+
+    tar.extractall(path, members, numeric_owner)
+
+
 def unzip_it(zip_path, extract_path=None):
     fp = pathlib.Path(zip_path)
     if extract_path is None:
@@ -227,7 +246,7 @@ def unzip_it(zip_path, extract_path=None):
         import tarfile
 
         with tarfile.open(fp) as tar:
-            tar.extractall(extract_path)
+            safe_extract(tar, extract_path)
     else:
         with zipfile.ZipFile(fp, "r") as zip_archive:
             zip_archive.extractall(extract_path)
@@ -242,7 +261,7 @@ def make_name_fem_ready(value, no_dot=False):
     :param no_dot:
     :return: Fixed name
     """
-    logging.debug("Converting bad name")
+    logger.debug("Converting bad name")
 
     if value[0] == "/":
         value = value[1:]
@@ -252,7 +271,7 @@ def make_name_fem_ready(value, no_dot=False):
         value = "_" + value
 
     if "/" in value:
-        logging.error(f'Character "/" found in {value}')
+        logger.error(f'Character "/" found in {value}')
 
     # if "-" in value:
     #     value = value.replace("-", "_")
@@ -261,7 +280,7 @@ def make_name_fem_ready(value, no_dot=False):
         value = value.replace(".", "_")
     final_name = value.strip()
     if len(final_name) > 25:
-        logging.info(f'Note FEM name "{final_name}" is >25 characters. This might cause issues in some FEM software')
+        logger.info(f'Note FEM name "{final_name}" is >25 characters. This might cause issues in some FEM software')
     return final_name
 
 
@@ -287,24 +306,12 @@ def flatten(t):
     return [item for sublist in t for item in sublist]
 
 
-def faceted_tol(units):
-    """
-
-    :param units:
-    :return:
-    """
-    if units == "m":
-        return 1e-2
-    else:
-        return 1
-
-
 def replace_node(old_node: Node, new_node: Node) -> None:
     from ada.fem import FemSet
 
     for elem in old_node.refs.copy():
         if isinstance(elem, FemSet):
-            logging.warning("replace_node does not support updating FemSet")
+            logger.warning("replace_node does not support updating FemSet")
             continue
 
         node_index = elem.nodes.index(old_node)
@@ -315,7 +322,7 @@ def replace_node(old_node: Node, new_node: Node) -> None:
         # new_node.refs.extend(old_node.refs)
         old_node.refs.pop(old_node.refs.index(elem))
         new_node.refs.append(elem)
-        logging.debug(f"{old_node} exchanged with {new_node} --> {elem}")
+        logger.debug(f"{old_node} exchanged with {new_node} --> {elem}")
 
 
 def replace_nodes_by_tol(nodes, decimals=0, tol=Settings.point_tol):
@@ -338,7 +345,7 @@ def replace_nodes_by_tol(nodes, decimals=0, tol=Settings.point_tol):
         elif not most_precise[0] and np.any(most_precise[1:]):
             return False
         elif decimals_ == 10:
-            logging.error(f"Recursion started at 0 decimals, but are now at {decimals_} decimals. Will proceed with n.")
+            logger.error(f"Recursion started at 0 decimals, but are now at {decimals_} decimals. Will proceed with n.")
             return True
         else:
             return n_is_most_precise(n, nearby_nodes_, decimals_ + 1)
@@ -352,13 +359,3 @@ def replace_nodes_by_tol(nodes, decimals=0, tol=Settings.point_tol):
 
 class UnitTypes:
     LENGTH = "length"
-
-
-def unit_length_conversion(ori_unit, value):
-    if value == "m" and ori_unit == "mm":
-        scale_factor = 0.001
-    elif value == "mm" and ori_unit == "m":
-        scale_factor = 1000
-    else:
-        raise ValueError(f'Unrecognized unit conversion from "{ori_unit}" to "{value}"')
-    return scale_factor
