@@ -5,7 +5,7 @@ from .concept import FEM
 from .constraints import Bc, Constraint, PredefinedField
 from .elements import Connector, Elem, Mass, Spring
 from .interactions import Interaction, InteractionProperty
-from .loads import Load, LoadCase, LoadGravity, LoadPressure
+from .loads import Load, LoadCase, LoadGravity, LoadPoint, LoadPressure
 from .outputs import FieldOutput, HistOutput
 from .sections import ConnectorSection, FemSection
 from .sets import FemSet
@@ -36,6 +36,7 @@ __all__ = [
     "Load",
     "LoadGravity",
     "LoadPressure",
+    "LoadPoint",
     "LoadCase",
     "FemSection",
     "Spring",
