@@ -1,11 +1,12 @@
 import pathlib
 import shutil
 
+from ada.fem.formats.abaqus.results.read_odb import convert_to_pckle
 from ada.fem.formats.utils import LocalExecute
 
 
 def run_abaqus(
-    inp_path,
+    inp_path: pathlib.Path,
     cpus=2,
     gpus=None,
     run_ext=False,
@@ -25,7 +26,12 @@ def run_abaqus(
     aba_exe = AbaqusExecute(
         inp_path, cpus=cpus, run_ext=run_ext, metadata=metadata, auto_execute=execute, run_in_shell=run_in_shell
     )
-    return aba_exe.run(exit_on_complete, run_cmd=run_cmd, bat_start_str=custom_bat_str)
+    out = aba_exe.run(exit_on_complete, run_cmd=run_cmd, bat_start_str=custom_bat_str)
+    odb_path = inp_path.with_suffix(".odb")
+    pickle_path = inp_path.with_suffix(".pckle")
+
+    convert_to_pckle(odb_path, pickle_path)
+    return out
 
 
 class AbaqusExecute(LocalExecute):
