@@ -1,4 +1,4 @@
 from .read_eigen_data import get_eigen_data
 from .read_results import read_calculix_results
 
-__all__ = [read_calculix_results, get_eigen_data]
+__all__ = ["read_calculix_results", "get_eigen_data"]
