@@ -3,10 +3,10 @@ from itertools import chain
 import meshio
 
 from ada.concepts.containers import Nodes
-from ada.concepts.levels import FEM, Assembly, Part
 from ada.concepts.points import Node
+from ada.concepts.spatial import Assembly, Part
 from ada.core.utils import Counter
-from ada.fem import Elem
+from ada.fem import FEM, Elem
 from ada.fem.containers import FemElements
 
 
