@@ -1,10 +1,11 @@
-import logging
-
 from ada import Section
+from ada.config import get_logger
 from ada.sections import SectionCat
 
 from .write_utils import write_ff
 
+logger = get_logger()
+
 
 def general_beam(sec: Section, sec_id) -> str:
     p = sec.properties
@@ -77,7 +78,7 @@ def flatbar(sec: Section, sec_id) -> str:
 
 def write_bm_section(sec: Section, sec_id: int) -> str:
     bt = SectionCat.BASETYPES
-    base_type = SectionCat.get_shape_type(sec)
+
     sec_map = {
         bt.ANGULAR: angular,
         bt.BOX: box,
@@ -90,12 +91,12 @@ def write_bm_section(sec: Section, sec_id: int) -> str:
 
     sec_str = general_beam(sec, sec_id)
 
-    sec_str_writer = sec_map.get(base_type, None)
-    if base_type == bt.GENERAL:
+    sec_str_writer = sec_map.get(sec.type, None)
+    if sec.type == bt.GENERAL:
         return sec_str
 
     if sec_str_writer is None:
-        logging.error(f'Unable to convert "{sec}". This will be exported as general section only')
+        logger.error(f'Unable to convert "{sec}". This will be exported as general section only')
 
     sec_str += sec_str_writer(sec, sec_id)
 
