@@ -1,4 +1,4 @@
 from .base_models import CarbonSteel, Metal
 from .plasticity_models import DnvGl16Mat, PlasticityModel
 
-__all__ = [CarbonSteel, Metal, DnvGl16Mat, PlasticityModel]
+__all__ = ["CarbonSteel", "Metal", "DnvGl16Mat", "PlasticityModel"]
