@@ -1,26 +1,27 @@
 from __future__ import annotations
 
-import logging
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, List, Tuple, Union
+from typing import TYPE_CHECKING
 
-from ada.base.non_physical_objects import Backend
-from ada.concepts.curves import CurvePoly
-from ada.config import Settings
+from ada.base.root import Root
+from ada.base.units import Units
+from ada.config import Settings, get_logger
 from ada.sections.categories import BaseTypes, SectionCat
 
 if TYPE_CHECKING:
-    from ada import Beam
+    from ada import Beam, CurvePoly, Pipe, PipeSegElbow, PipeSegStraight
     from ada.fem import FemSection
 
+logger = get_logger()
 
-class Section(Backend):
+
+class Section(Root):
     TYPES = BaseTypes
 
     def __init__(
         self,
         name,
-        sec_type=None,
+        sec_type: BaseTypes | str = None,
         h=None,
         w_top=None,
         w_btn=None,
@@ -33,16 +34,21 @@ class Section(Backend):
         parent=None,
         sec_str=None,
         from_str=None,
-        outer_poly=None,
-        inner_poly=None,
+        outer_poly: CurvePoly = None,
+        inner_poly: CurvePoly = None,
         genprops: GeneralProperties = None,
         metadata=None,
-        units="m",
-        ifc_elem=None,
+        units=Units.M,
         guid=None,
         refs=None,
     ):
-        super(Section, self).__init__(name, guid, metadata, units, ifc_elem=ifc_elem, parent=parent)
+        super(Section, self).__init__(name=name, guid=guid, metadata=metadata, units=units, parent=parent)
+        if isinstance(sec_type, str):
+            sec_type_in = sec_type
+            sec_type = BaseTypes.from_str(sec_type_in)
+            if sec_type is None:
+                raise ValueError(f"Unrecognized section type {sec_type_in}]")
+
         self._type = sec_type
         self._h = h
         self._w_top = w_top
@@ -60,58 +66,26 @@ class Section(Backend):
         self._ifc_profile = None
         self._ifc_beam_type = None
 
-        if ifc_elem is not None:
-            props = self._import_from_ifc_profile(ifc_elem)
-            self.__dict__.update(props.__dict__)
-
         if from_str is not None:
             from ada.sections.utils import interpret_section_str
 
-            if units == "m":
+            if units == Units.M:
                 scalef = 0.001
-            elif units == "mm":
+            elif units == Units.MM:
                 scalef = 1.0
             else:
                 raise ValueError(f'Unknown units "{units}"')
+
             sec, tap = interpret_section_str(from_str, scalef, units=units)
             self.__dict__.update(sec.__dict__)
-        elif outer_poly:
-            self._type = "poly"
 
         self._genprops = None
         self._refs = refs if refs is not None else []
         if genprops is not None:
             genprops.parent = self
             self._genprops = genprops
-        # prop = self.properties
-        # if None in (prop.Cy, prop.Cz) and self.type != Section.TYPES.GENERAL:
-        #     logging.warning("Attribute Cy and Cz is missing from instance of Properties")
-
-    # def __eq__(self, other: Section):
-    #     props_equal = self.equal_props(other)
-    #     if props_equal is False:
-    #         return False
-    #     if other.name != self.name:
-    #         return False
-    #
-    #     return True
-
-    def _generate_ifc_section_data(self):
-        from ada.ifc.write.write_sections import export_beam_section
-
-        return export_beam_section(self)
-
-    def _import_from_ifc_profile(self, ifc_elem):
-        from ada.ifc.read.read_beam_section import import_section_from_ifc
-
-        self._ifc_profile = ifc_elem
-        return import_section_from_ifc(ifc_elem)
 
     def equal_props(self, other: Section):
-        props = ["type", "h", "w_top", "w_btn", "t_w", "t_ftop", "t_fbtn", "r", "wt", "poly_outer", "poly_inner"]
-        if self.type == self.TYPES.GENERAL:
-            props += ["properties"]
-
         for propa, propb in zip(self.unique_props(), other.unique_props()):
             if propa != propb:
                 return False
@@ -120,10 +94,12 @@ class Section(Backend):
 
     def unique_props(self):
         props = ["type", "h", "w_top", "w_btn", "t_w", "t_ftop", "t_fbtn", "r", "wt", "poly_outer", "poly_inner"]
+        if self.type == self.TYPES.GENERAL:
+            props += ["properties"]
         return tuple([getattr(self, p) for p in props])
 
     @property
-    def type(self):
+    def type(self) -> BaseTypes:
         return self._type
 
     @property
@@ -198,26 +174,32 @@ class Section(Backend):
         def s(x):
             return x / 0.001
 
-        if self.type in SectionCat.box + SectionCat.igirders + SectionCat.tprofiles + SectionCat.shs + SectionCat.rhs:
-            sec_str = "{}{:g}x{:g}x{:g}x{:g}".format(self.type, s(self.h), s(self.w_top), s(self.t_w), s(self.t_ftop))
-        elif self.type in SectionCat.tubular:
-            sec_str = "{}{:g}x{:g}".format(self.type, s(self.r), s(self.wt))
-        elif self.type in SectionCat.circular:
-            sec_str = "{}{:g}".format(self.type, s(self.r))
-        elif self.type in SectionCat.angular:
-            sec_str = "{}{:g}x{:g}".format(self.type, s(self.h), s(self.t_w))
-        elif self.type in SectionCat.iprofiles:
+        if self.type == BaseTypes.BOX:
+            sec_str = "{}{:g}x{:g}x{:g}x{:g}".format(
+                self.type.value, s(self.h), s(self.w_top), s(self.t_w), s(self.t_ftop)
+            )
+        elif self.type == BaseTypes.TUBULAR:
+            sec_str = "{}{:g}x{:g}".format(self.type.value, s(self.r), s(self.wt))
+        elif self.type == BaseTypes.CIRCULAR:
+            sec_str = "{}{:g}".format(self.type.value, s(self.r))
+        elif self.type == BaseTypes.ANGULAR:
+            sec_str = "{}{:g}x{:g}".format(self.type.value, s(self.h), s(self.t_w))
+        elif self.type == BaseTypes.IPROFILE:
             sec_str = self._sec_str
-        elif self.type in SectionCat.channels:
-            sec_str = "{}{:g}".format(self.type, s(self.h))
-        elif self.type in SectionCat.general:
-            sec_str = "{}{}".format(self.type, self.id)
-        elif self.type in SectionCat.flatbar:
-            sec_str = f"{self.type}{s(self.h)}x{s(self.w_top)}"
-        elif self.type == "poly":
+        elif self.type == BaseTypes.TPROFILE:
+            sec_str = "{}{:g}x{:g}x{:g}".format(self.type.value, s(self.h), s(self.w_top), s(self.t_w))
+        elif self.type == BaseTypes.CHANNEL:
+            sec_str = "{}{:g}".format(self.type.value, s(self.h))
+        elif self.type == BaseTypes.GENERAL:
+            sec_str = "{}{}".format(self.type.value, self.id)
+        elif self.type == BaseTypes.FLATBAR:
+            sec_str = f"{self.type.value}{s(self.h)}x{s(self.w_top)}"
+        elif self.type == BaseTypes.POLY:
             sec_str = "PolyCurve"
+
         else:
             raise ValueError(f'Section type "{self.type}" has not been given a section str')
+
         return sec_str.replace(".", "_") if sec_str is not None else None
 
     @property
@@ -235,10 +217,10 @@ class Section(Backend):
 
     @units.setter
     def units(self, value):
+        if isinstance(value, str):
+            value = Units.from_str(value)
         if self._units != value:
-            from ada.core.utils import unit_length_conversion
-
-            scale_factor = unit_length_conversion(self._units, value)
+            scale_factor = Units.get_scale_factor(self._units, value)
 
             if self.poly_inner is not None:
                 self.poly_inner.scale(scale_factor, Settings.point_tol)
@@ -254,18 +236,6 @@ class Section(Backend):
                         self.__dict__[key] *= scale_factor
             self._units = value
 
-    @property
-    def ifc_profile(self):
-        if self._ifc_profile is None:
-            self._ifc_profile, self._ifc_beam_type = self._generate_ifc_section_data()
-        return self._ifc_profile
-
-    @property
-    def ifc_beam_type(self):
-        if self._ifc_beam_type is None:
-            self._ifc_profile, self._ifc_beam_type = self._generate_ifc_section_data()
-        return self._ifc_beam_type
-
     @property
     def poly_outer(self) -> CurvePoly:
         return self._outer_poly
@@ -288,7 +258,7 @@ class Section(Backend):
         display(HBox([fig, html]))
 
     @property
-    def refs(self) -> List[Union[Beam, FemSection]]:
+    def refs(self) -> list[Beam | FemSection | Pipe | PipeSegStraight | PipeSegElbow]:
         return self._refs
 
     def __hash__(self):
@@ -315,7 +285,7 @@ class SectionParts:
 
 @dataclass
 class GeneralProperties:
-    parent: Section = field(default=None, compare=False)
+    parent: Section = field(default=None, compare=False, repr=False)
     Ax: float = None
     Ix: float = None
     Iy: float = None
@@ -335,6 +305,30 @@ class GeneralProperties:
     Cy: float = None
     Cz: float = None
 
+    def __hash__(self):
+        return hash(
+            (
+                self.Ax,
+                self.Ix,
+                self.Iy,
+                self.Iz,
+                self.Iyz,
+                self.Wxmin,
+                self.Wymin,
+                self.Wzmin,
+                self.Shary,
+                self.Sharz,
+                self.Shceny,
+                self.Shcenz,
+                self.Sy,
+                self.Sz,
+                self.Sfy,
+                self.Sfz,
+                self.Cy,
+                self.Cz,
+            )
+        )
+
     @property
     def modified(self) -> bool:
         """Returns true if attributes are not equal to the calculated properties of the parent section"""
@@ -353,32 +347,29 @@ class SectionProfile:
     is_solid: bool
     outer_curve: CurvePoly = None
     inner_curve: CurvePoly = None
-    outer_curve_disconnected: List[CurvePoly] = None
-    inner_curve_disconnected: List[CurvePoly] = None
+    outer_curve_disconnected: list[CurvePoly] = None
+    inner_curve_disconnected: list[CurvePoly] = None
     disconnected: bool = None
-    shell_thickness_map: List[Tuple[str, float]] = None
+    shell_thickness_map: list[tuple[str, float]] = None
 
 
 def build_section_profile(sec: Section, is_solid) -> SectionProfile:
     import ada.sections.profiles as profile_builder
 
-    section_shape_type = SectionCat.get_shape_type(sec)
-
-    if section_shape_type in SectionCat.tubular + SectionCat.circular + SectionCat.general:
-        logging.info("Tubular profiles do not need curve representations")
+    if sec.type in [BaseTypes.TUBULAR, BaseTypes.CIRCULAR, BaseTypes.GENERAL]:
+        logger.info("Tubular profiles do not need curve representations")
         return SectionProfile(sec, is_solid)
 
-    sec_type = SectionCat.BASETYPES
     build_map = {
-        sec_type.ANGULAR: profile_builder.angular,
-        sec_type.IPROFILE: profile_builder.iprofiles,
-        sec_type.TPROFILE: profile_builder.tprofiles,
-        sec_type.BOX: profile_builder.box,
-        sec_type.FLATBAR: profile_builder.flatbar,
-        sec_type.CHANNEL: profile_builder.channel,
+        BaseTypes.ANGULAR: profile_builder.angular,
+        BaseTypes.IPROFILE: profile_builder.iprofiles,
+        BaseTypes.TPROFILE: profile_builder.tprofiles,
+        BaseTypes.BOX: profile_builder.box,
+        BaseTypes.FLATBAR: profile_builder.flatbar,
+        BaseTypes.CHANNEL: profile_builder.channel,
     }
 
-    section_builder = build_map.get(section_shape_type, None)
+    section_builder = build_map.get(sec.type, None)
 
     if section_builder is None and sec.poly_outer is None:
         raise ValueError("Currently geometry build is unsupported for profile type {ptype}".format(ptype=sec.type))
